/*
 * Copyright 1994, 1995 Vectaport Inc.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation for any purpose is hereby granted without fee, provided
 * that the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the names of the copyright holders not be used in
 * advertising or publicity pertaining to distribution of the software
 * without specific, written prior permission.  The copyright holders make
 * no representations about the suitability of this software for any purpose.
 * It is provided "as is" without express or implied warranty.
 *
 * THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
 * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 * 
 */

#ifndef mapstates_h
#define mapstates_h

#include <IVGlyph/namestate.h>
class ProjectionState : public NameState {
public:
    ProjectionState(const char* =nil, const char** params =nil);
    virtual ~ProjectionState();

    const char* projection();
    const char** params();
    void projection(const char*, const char**, boolean notif =true);
protected:
    char* _projection;
    const char** _parms;
};

class MapFClassState : public NameState {
public:
    MapFClassState(const char*, const char*);
    virtual ~MapFClassState();

    const char* mapfclass();
    const char* mapfclassdesc();
    void mapfclass(const char*, const char*, boolean notif =true);
protected:
    char* _mapfclass;
    char* _mapfclassdesc;
    char buf[256];
};

class MapCovState : public NameState {
public:
    MapCovState(MapFClassState*, const char*, const char*);
    virtual ~MapCovState();

    const char* mapcov();
    const char* mapcovdesc();
    void mapcov(const char*, const char*, boolean notif =true);
protected:
    char* _mapcov;
    char* _mapcovdesc;
    MapFClassState* _fcstate;
    char buf[256];
};

class MapLibState : public NameState {
public:
    MapLibState(MapCovState*, const char*);
    virtual ~MapLibState();

    const char* maplib();
    void maplib(const char*, boolean notif =true);
protected:
    char* _maplib;
    MapCovState* _covstate;
    char buf[256];
};

class MapDbState : public NameState {
public:
    MapDbState(MapLibState*, const char*);
    virtual ~MapDbState();

    const char* mapdb();
    void mapdb(const char*, boolean =false);
protected:
    MapLibState* _libstate;
    char* _mapdb;
    char buf[256];
};

class MapSelectionState : public NameState {
public:
    MapSelectionState(const char*);
    virtual ~MapSelectionState();

    const char* mapselection();
    void mapselection(const char*, boolean notif =true);
protected:
    char* _mapselection;
    char buf[256];
};

#endif
